@@ -56,7 +56,7 @@ def timestamp_toString(stamp: int) -> str:
     :param stamp: 1577808000
     :return: '2020-01-01'
     """
-    return time.strftime("%Y-%m-%d-%H", time.localtime(stamp))
+    return time.strftime("%Y-%m-%d", time.localtime(stamp))
 
 
 def datetime_toTimestamp(dateTime):
@@ -222,16 +222,21 @@ def monitoring_run_time(f):
 @retry(stop_max_attempt_number=10)
 def get_taobao_time():
     """获取苏宁时间{"sysTime2":"2021-01-12 16:41:50","sysTime1":"20210112164150"}"""
-    url = 'http://quan.suning.com/getSysTime.do'
-    ts = requests.get(url)
-    print(ts.text)
-    if ts.status_code == 200:
-        json_data = json.loads(ts.text)
-        return json_data
-    else:
-        json_data = {"sysTime2":datetime_toString_detail(datetime.datetime.now()),"sysTime1":f"{datetime_toTimestamp(datetime.datetime.now())}"}
+    try:
+        url = 'http://10.228.84.20:21000/get_local_timestamp'
+        ts = requests.get(url)
+        if ts.status_code == 200:
+            json_data = json.loads(ts.text)
+            return {"sysTime2": timestamp_toString(json_data.get('time')),"sysTime1": f"{json_data.get('time')}"}
+        else:
+            json_data = {"sysTime2": datetime_toString_detail(datetime.datetime.now()),
+                         "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
+            return json_data
+    except:
+        json_data = {"sysTime2": datetime_toString_detail(datetime.datetime.now()),"sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
         return json_data
+
 if __name__ == '__main__':
-    month_begin_day = month_datelist('2020-01')
-    print(getdate(1))
-    get_taobao_time()
+    # month_begin_day = month_datelist('2020-01')
+    # print(getdate(1))
+    print(get_taobao_time())
